#
# spec file for package xfce4-mailwatch-plugin
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define panel_version 4.14.0
%define plugin mailwatch
%bcond_with git
Name:           xfce4-%{plugin}-plugin
Version:        1.3.1
Release:        1.6
Summary:        Versatile Mail Checking Plugin for the Xfce Panel
License:        GPL-2.0-only
Group:          System/GUI/XFCE
URL:            https://goodies.xfce.org/projects/panel-plugins/xfce4-mailwatch-plugin
Source0:        https://archive.xfce.org/src/panel-plugins/xfce4-mailwatch-plugin/1.3/%{name}-%{version}.tar.bz2
BuildRequires:  ed
BuildRequires:  fdupes
BuildRequires:  intltool
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(exo-2) >= 0.11.0
BuildRequires:  pkgconfig(glib-2.0) >= 2.42.0
BuildRequires:  pkgconfig(gnutls) >= 1.2.0
BuildRequires:  pkgconfig(gobject-2.0) >= 2.42.0
BuildRequires:  pkgconfig(gthread-2.0) >= 2.42.0
BuildRequires:  pkgconfig(gtk+-3.0) >= 3.22.0
BuildRequires:  pkgconfig(libxfce4panel-2.0) >= %{panel_version}
BuildRequires:  pkgconfig(libxfce4ui-2) >= 4.14.0
BuildRequires:  pkgconfig(libxfce4util-1.0) >= 4.14.0
%if %{with git}
BuildRequires:  xfce4-dev-tools
%endif
Recommends:     %{name}-lang = %{version}
Requires:       xfce4-panel >= %{panel_version}
# package was renamed in 2019 after Leap 15.1
Provides:       xfce4-panel-plugin-%{plugin} = %{version}-%{release}
Obsoletes:      xfce4-panel-plugin-%{plugin} < %{version}-%{release}
Obsoletes:      xfce4-panel-plugin-%{plugin}-debuginfo

%description
The Mailwatch plugin is a multi-protocol, multi-mailbox mail checking tool
which supports a variety of protocols and local mailbox formats. It can check
multiple locations and execute custom actions when it finds new mail.

%package lang
Summary:        Translations for package %{name}
Group:          System/Localization
Requires:       %{name} = %{version}
Supplements:    %{name}
Provides:       %{name}-lang-all = %{version}
# package was renamed in 2019 after Leap 15.1
Obsoletes:      xfce4-panel-plugin-%{plugin}-lang < %{version}-%{release}
Provides:       xfce4-panel-plugin-%{plugin}-lang = %{version}-%{release}
BuildArch:      noarch

%description lang
Provides translations for the "%{name}" package.

%prep
%autosetup
# fix up missing icon
ed -s panel-plugin/mailwatch.desktop.in 2>/dev/null <<'EOF'
,s/^Icon=xfce-mail/Icon=mail-unread/
w
EOF

%build
%configure --disable-static
make %{_smp_mflags} V=1

%install
%make_install

rm %{buildroot}%{_libdir}/xfce4/panel/plugins/libmailwatch.la

rm -rf %{buildroot}%{_datadir}/locale/{ast,kk,tl_PH,ur_PK}

%find_lang %{name} %{name}.lang %{?no_lang_C}

%files
%doc AUTHORS NEWS README
%license COPYING
%{_libdir}/xfce4/panel/plugins/libmailwatch.so
%{_datadir}/xfce4/panel/plugins/mailwatch.desktop
%{_datadir}/icons/hicolor/*/apps/*

%files lang -f %{name}.lang

%changelog
* Fri Apr 21 2023 Manfred Hollstein <manfred.h@gmx.net>
- Update to version 1.3.1
  * Update copyright year
  * Remove deprecated project files
  * Add remote-event functionality - fixes #51
  * build: Fix autotools warnings
  * Fix remaining blurry icons when UI scale > 1
  * Use "logo-icon-name" instead of "logo" in about dialog
  * Remove soon-to-be-deprecated exo-string functions
  * Fix intltool lock file problem during make distcheck
  * Update COPYING
  * Fix compilation warnings
  * autoconf: Some updates
  * Add "View Log..." menu item
  * Update log status on force mail update
  * Fix missing-prototypes
  * Translation Updates
- Remove _service file
* Mon Nov  9 2020 Maurizio Galli <maurizio.galli@gmail.com>
- Update to version 1.3.0
  - GTK 3 Port
  - Remove Libgcrypt dependency
  - Move "watching" column to the left to avoid overlapping with
    scrollbar
  - Add support for XfceTitledDialog new API
  - Fix cast to pointer
  - Replace deprecated GTimeVal
  - Update URLs from goodies.x.o to docs.x.o (bxo#16167)
  - Added support for multi-row/column panels in xfce4-panel > 4.9
  - Fix running command on each change of the count
  - Fix running an empty command
  - Do not run command when new message count is 0
  - Add SSL support CFLAGS and LDFLAGS conditionally
  - Translation Updates
* Fri Aug 16 2019 Maurizio Galli <maurizio.galli@gmail.com>
- Fixed sources in spec file
* Tue Jul 16 2019 Maurizio Galli <maurizio.galli@gmail.com>
- Package renamed to follow upstream name xfce4-foo-plugin
- Use lang subpackage for manual edits instead of %%lang_package macro
- Cleaned up spec file
- Added bcond for git master builds
- Only add NEWS and omit Changelog
- Move COPYING under %%license macro
* Thu Oct 24 2013 gber@opensuse.org
- fix URL
* Thu Oct 24 2013 gber@opensuse.org
- update to version 1.2.0
  - Fix recieving data from multiple packets
  - Port to libxfce4ui
  - Fix compilation and linking with libgcrypt
  - Fix compilation error when using gnutls >= 3.0.3
  - Fix build when SSL is disabled
  - Also support gtk-2.12-style tooltips, and make the tooltip
    auto-update in place if the status changes while the tooltip is
    active
  - Fix high CPU usage while checking mail
  - Add new help dialog with redirection
  - Remove a moved documentation
  - Add configured features to print
  - Use exo icon chooser dialog for icon selection
  - Drop the old panel support
  - Translation updates
- dropped
  xfce4-panel-plugin-mailwatch-1.1.0-fix-high-cpu-usage-while-checking-mail.patch,
  xfce4-panel-plugin-mailwatch-1.1.0-fix-build-with-4.7.patch,
  xfce4-panel-plugin-mailwatch-1.1.0-fix-gnutls-3.0.3.patch,
  xfce4-panel-plugin-mailwatch-1.1.0-use-docdir.patch,
  xfce4-panel-plugin-mailwatch-1.1.0-set-mail-interval.patch,
  xfce4-panel-plugin-mailwatch-1.1.0-fix-format-sting-errors.patch,
  xfce4-panel-plugin-mailwatch-link-against-libgcrypt.patch,
  xfce4-panel-plugin-mailwatch-automake-1.13.patch
* Wed Mar 13 2013 pgajdos@suse.cz
- builds with automake 1.13
  * automake-1.13.patch
* Mon May  7 2012 gber@opensuse.org
- fix help function by depending on libxfce4ui-tools which provides
  xfhelp4 again
* Fri Apr 20 2012 gber@opensuse.org
- corrected license
* Tue Apr 17 2012 gber@opensuse.org
- corrected source URL
* Tue Apr 17 2012 gber@opensuse.org
- corrected source URL
- use pristine source tarball
* Wed Apr  4 2012 gber@opensuse.org
- dixed missing icon
* Tue Apr  3 2012 gber@opensuse.org
- added xfce4-panel-plugin-mailwatch-1.1.0-set-mail-interval.patch
  which fixes a problem with the interval not being set correctly
  (bxo#6947)
- added xfce4-panel-plugin-mailwatch-1.1.0-fix-format-sting-errors.patch
  which fixes some format string errors (bxo#8063)
- added xfce4-panel-plugin-mailwatch-link-against-libgcrypt.patch
  in order to link agains libgcrypt
- specfile cleanup
- correct dependencies
- split off -lang subpackage
* Thu Oct 20 2011 gber@opensuse.org
- added xfce4-panel-plugin-mailwatch-1.1.0-use-docdir.patch in
  order to use docdir correctly
- install HTML documentation below
  /usr/share/xfce4/xfce4-mailwatch-plugin/html/
- package AUTHORS ChangeLog COPYING NEWS README TODO
* Sun Sep 25 2011 gber@opensuse.org
- added xfce4-panel-plugin-mailwatch-1.1.0-fix-gnutls-3.0.3.patch
  in order to fix the build with gnutls >= 3.0.3, a lowat level of
  0 is the default in gnutls >= 2.12.0 and
  gnutls_transport_set_lowat() has been removed in 3.0.3
* Fri Sep 16 2011 andrea.turrini@gmail.com
- Fixed typos in xfce4-panel-plugin-mailwatch.spec
* Wed Aug 24 2011 crrodriguez@opensuse.org
- Fix build in Factory
* Wed Mar  9 2011 gber@opensuse.org
- new package (split off from xfce4-panel-plugins)
